measuretools.move_full_measure_tuplet_prolation_to_measure_time_signature
=========================================================================

.. autofunction:: abjad.tools.measuretools.move_full_measure_tuplet_prolation_to_measure_time_signature.move_full_measure_tuplet_prolation_to_measure_time_signature
   :noindex:
